Module utils

Module utils 

Some basic tools

Functions

get_random_from_tokens
Get a random token from a named metadata Tokens.
read_file_as_vecs
Read a file and convert each line to a vector of bytes.
replay
Replay inputs from files using the provided harness function.
save_queue
Save input queue to a directory.
setup_logger
Initialize a logger
show_seed
Display the content of a seed file.