Some basic tools
Functions
- get_
random_ from_ tokens - Get a random token from a named metadata Tokens.
- read_
file_ as_ vecs - Read a file and convert each line to a vector of bytes.
- replay
- Replay inputs from files using the provided harness function.
- save_
queue - Save input queue to a directory.
- setup_
logger - Initialize a logger
- show_
seed - Display the content of a seed file.